﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace EnvioSMS
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
            cbMetodo.SelectedItem = "Modem";

            Twilio.TwilioClient.Init("SID", "TOKEN");
        }

        private void btEnviar_Click(object sender, EventArgs e)
        {
            try
            {
                switch (cbMetodo.SelectedItem.ToString())
                {
                    case "Modem":
                        EnviarModem();
                        break;
                    case "Twilio":
                        EnviarTwilio();
                        break;
                    case "Ipipi":
                        EnviarIpipi();
                        break;
                    case "ViaNett":
                        EnviarViaNett();
                        break;
                    case "LocaSMS":
                        EnviarLocaSMS();
                        break;
                }
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Erro", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        private void EnviarModem()
        {
            using (var port = new System.IO.Ports.SerialPort())
            {
                port.PortName = "COM5";
                port.Open();
                port.DtrEnable = true;
                port.RtsEnable = true;
                port.Write("AT\r"); // iniciando a comunicação
                port.Write("AT+CMGF=1\r"); // setando a comunicação para o modo texto
                port.Write(string.Format("AT+CMGS=\"{0}\"\r", tbTelefone.Text)); // setando o número do destinatário
                port.Write(tbMensagem.Text + char.ConvertFromUtf32(26)); // enviando a mensagem
            }
        }

        private void EnviarTwilio()
        {
            var resultado = Twilio.Rest.Api.V2010.Account.MessageResource.Create(
                to: new Twilio.Types.PhoneNumber(tbTelefone.Text),
                from: new Twilio.Types.PhoneNumber("SEU_NUMERO_TWILIO"),
                body: tbMensagem.Text);
        }

        private void EnviarIpipi()
        {
            using (var ipipiAuth = new IpipiAuth.AuthenticationSoapClient("AuthenticationSoap"))
            using (var ipipi = new Ipipi.SMSSoapClient("SMSSoap"))
            {
                var authInfo = ipipiAuth.GetParameters("user", "pwd");
                var resultado = ipipi.Send_Plain(authInfo.Token, authInfo.Signature, tbTelefone.Text, tbMensagem.Text, Ipipi.SmsEncoding.Seven);
                //var resultado = ipipi.Send_Plain("token", "signature", tbTelefone.Text, tbMensagem.Text, Ipipi.SmsEncoding.Seven);
            }
        }

        private void EnviarViaNett()
        {
            using (var vianett = new ViaNett.CPAWebServiceSoapClient("CPAWebServiceSoap12"))
            {
                var resultado = vianett.SendSMS_Simple1(
                    "USER", "PWD",
                    Convert.ToInt64(tbTelefone.Text.Replace("+", string.Empty)),
                    tbMensagem.Text);
            }
        }

        private void EnviarLocaSMS()
        {
            using (var locasms = new LocaSMS.ServiceSMSSoapClient())
            {
                var resultado = locasms.SendSMS("USER", "PWD",
                    new LocaSMS.rSMS()
                    {
                        Destinations = new [] 
                        {
                            new LocaSMS.Destination()
                            {
                                Number = tbTelefone.Text
                            }
                        },
                        Msg = tbMensagem.Text
                    });
            }
        }
    }
}
